function [sk,se,qq,sk_u,se_u,qq_u] =...
    constr_closed(kk,rr,sk_start,se_start,qq_start,sebar,X_Q,X_Y,d1,barrier);

% optimal (sk,se,qq) given (kk,rr) subject to the constraint
    % kk: detrended capital stock
    % rr: detrended co-stage
    % sk_start: starting value for sector 1's share of capital stock
    % se_start: starting value for sector 1's share of labor
    % qq_start: starting value for qq (detrended relative price)
    % sebar: lower bound for se
    % X_Q: trend for the relative price
    % X_Y: trend for sector 2 output
    % d1: minimum food consumption
    % barrier: equals 1 if the lower bound is present, 0 otherwise
x0=[sk_start;se_start;qq_start];
options=optimset('Display','none','TolFun',1e-14);   % Option to display output
x = fsolve('sk_se_and_qq',x0,options,kk,rr,X_Q,X_Y,d1); 
                    % calculates (sk,se,qq) without labor barrier
sk_u=x(1);
se_u=x(2);
qq_u=x(3);
if barrier==1 & se_u<sebar;
   se=sebar;  % se equals sebar if labor barrier is binding
   x0=[sk_u;qq_u];
   options=optimset('Display','none','TolFun',1e-14);   % Option to display output
   x=fsolve('sk_and_qq_given_se',x0,options,kk,rr,se,X_Q,X_Y,d1);  
                    % calculates (sk,qq) with the barrier
   sk=x(1);
   qq=x(2);
else;
   sk=sk_u;
   se=se_u;
   qq=qq_u;
end;