function F = dynamical_system_closed(kk_0,rr_0,sk_start,se_start,qq_start,...
                sebar_0,sebar_1,X_Q_0,X_Q_1,X_Y_0,X_Y_1,...
                POP_0,POP_1,psi_0,delta_0,delta_1,tau_1,...
                d1_0,d1_1,barrier);

global alpha1 phi;
    % alpha1: material input share in sector 1
    % phi: cost of financial intermediation for sector 2 capital

options=optimset('Display','none','TolFun',1e-14);   % Option to display output


% mapping from (kk,rr,qq) to (kk,rr,qq) next period
    % kk_0: current kk (detrended capital stock)
    % rr_0: current rr (detrended co-state)
    % sk_start: starting value for sk
    % se_start: starting value for se
    % qq_start: starting value for qq
    % sebar_0: current value of lower bound for se (sector 1's labor share)
    % sebar_1: sebar next period
    % X_Q_0: current value of X_Q (trend for relative price)
    % X_Y_0: current valu eof X_Y (trend for sector 2 output)
    % X_Q_1: X_Q next period
    % X_Y_1: X_Y next period
    % POP_0: current working-age population
    % POP_1: POP next period
    % psi_0: current value of government share of sector 2 output
    % delta_0: current value of delta (depreciation rate)
    % delta_1: delta next period
    % tau_1: capital income tax rate next period
    % d1_0: minimum food consumption
    % d1_1: minimum food consumption next period
    % barrier: 1 if lower bound for se (sector 1's labor share), 0 otherwise

[sk_0,se_0,qq_0,sk_u,se_u,qq_u]=...
          constr_closed(kk_0,rr_0,sk_start,se_start,qq_start,sebar_0,...
          X_Q_0,X_Y_0,d1_0,barrier);
            % current value of (sk,se,qq) with and without labor barrier
            
% update kk
kk_1=((POP_0*X_Y_0)/(POP_1*X_Y_1))* ...
     (...
     (1-delta_0-(1-sk_0)*phi)*kk_0+(1-psi_0)*y2_f(sk_0,se_0,kk_0,qq_0) ...
      - alpha1*qq_0*y1_f(sk_0,se_0,kk_0,qq_0)...
      - c2_f(X_Q_0,X_Y_0,qq_0,rr_0)/X_Y_0 ...
      );
 
% update rr
rr_1=fsolve('euler_closed',rr_0,options,...
      kk_1,rr_0,sk_u,se_u,qq_u,sebar_1,X_Q_1,X_Y_0,X_Y_1,...
      delta_1,tau_1,d1_1,barrier);

F(1)=kk_1;
F(2)=rr_1;