function F = dynamical_system_open(kk_0,rr_0,sk_start,se_start,...
                sebar_0,sebar_1,X_Q_0,X_Q_1,X_Y_0,X_Y_1,...
                qq_0,qq_1,POP_0,POP_1,psi_0,delta_0,delta_1,tau_1,...
                d1_0,barrier);
              

global alpha1 alpha2 beta phi;
    % alpha1: material input share in sector 1
    % alpha2: material input share in sector 2
    % phi: cost of financial intermediation for sector 2 capital

options=optimset('Display','none','TolFun',1e-14);   % Option to display output


% mapping from (kk,rr) to (kk,rr) next period, given qq
    % kk_0: current kk (detrended capital stock)
    % rr_0: current rr (detrended co-state)
    % sk_start: starting value for sk
    % se_start: starting value for se
    % sebar_0: current value of lower bound for se (sector 1's labor share)
    % sebar_1: sebar next period
    % X_Q_0: current value of X_Q (trend for relative price)
    % X_Y_0: current valu eof X_Y (trend for sector 2 output)
    % X_Q_1: X_Q next period
    % X_Y_1: X_Y next period
    % qq_0: current value of qq (detrended relative price)
    % qq_1: qq next period
    % POP_0: current working-age population
    % POP_1: POP next period
    % psi_0: current value of government share of sector 2 output
    % delta_0: current value of delta (depreciation rate)
    % delta_1: delta next period
    % tau_1: capital income tax rate next period
    % d1_0: d1 (minimum consumption this period)
    % barrier: 1 if lower bound for se (sector 1's labor share), 0 otherwise
    
[sk_0,se_0,sk_u,se_u]=...
      constr_open(kk_0,sk_start,se_start,sebar_0,qq_0,barrier);
        % current value of (sk,se) with and without labor barrier
% update kk
kk_1=(POP_0*X_Y_0/(POP_1*X_Y_1))* ...
     (...
      (1-delta_0-(1-sk_0)*phi)*kk_0+(1-psi_0)*y2_f(sk_0,se_0,kk_0,qq_0) ...
        - alpha1*qq_0*y1_f(sk_0,se_0,kk_0,qq_0)...
        - c2_f(X_Q_0,X_Y_0,qq_0,rr_0)/X_Y_0...
        + qq_0*(y1_f(sk_0,se_0,kk_0,qq_0)...
        - c1_f(X_Q_0,X_Y_0,qq_0,rr_0,d1_0)/(X_Y_0/X_Q_0))...
        - alpha2*y2_f(sk_0,se_0,kk_0,qq_0)...
      );
% update rr
[sk_1,se_1,sk_u,se_u]=constr_open(kk_1,sk_u,se_u,sebar_1,qq_1,barrier);
        % next period value of (sk,se) with and without labor barrier
rr_1 = (beta*rr_0*(1+(1-tau_1)*(r2_f(sk_1,se_1,kk_1,qq_1)-phi-delta_1)))/(X_Y_1/X_Y_0);

F(1)=kk_1;
F(2)=rr_1;