function F = euler_closed(x,kk_1,rr_0,sk_start,se_start,qq_start,...
                        sebar_1,X_Q_1,X_Y_0,X_Y_1,delta_1,tau_1,d1_1,barrier);

global beta phi;
    % beta: discounting factor
    % phi: cost of financial intermediation for sector 2 capital

% Euler equation
    % x: next period's rr
    % kk_1: next period's kk (detrended capital stock)
    % rr_0: this period's rr (detrended co-state)
    % sk_start: starting value for sk (sector 1's capital share) next period
    % se_start: starting value for se (sector 1's share of labor) next period
    % qq_start: starting value for qq (detrended co-state) next period
    % sebar_1: sebar (lower bound for se (sector 1's labor share)) next period
    % X_Q_1: next period's X_Q (trend for relative price)
    % X_Y_0: this period's trend for sector 2 output
    % X_Y_1: next period's trend for sector 2 output
    % delta_1: depreciation rate next period
    % tau_1: capital tax rate for next period
    % d1_1: minimum food consumption next period
    % barrier: equals 1 if the lower bound is present, 0 otherwise

[sk_1,se_1,qq_1,sk_u,se_u,q_u]=...
        constr_closed(kk_1,x,sk_start,se_start,qq_start,...
        sebar_1,X_Q_1,X_Y_1,d1_1,barrier);
F = beta*rr_0*(1+(1-tau_1)*(r2_f(sk_1,se_1,kk_1,qq_1)-phi-delta_1))...
    - x*(X_Y_1/X_Y_0);