%
% graph_r2.m
% 

delete graph_r2.out;
diary graph_r2.out;
clear all;clc;echo off;


global alpha1 alpha2 beta theta1 theta2 eta mu1 mu2 phi;
    % alpha1: material input share in sector 1
    % alpha2: material input share in sector 2
    % beta: discounting factor
    % theta1: capital share in sector 1
    % theta2: capital share in sector 2
    % eta: labor share in sector 1
    % mu1: food share in the utility function
    % mu2: non-food share in the utility function, equals 1-mu1
    % phi: cost of financial intermediation for sector 2 capital


% Determine the reference year
baseyear=1;
rr_0=xlsread('prewar_dataset','parameters','l6');
    % rr in baseyear with barrier and with frac_d1=0.9
    

% Calibrated parameter values
x=xlsread('prewar_dataset','parameters','b2:b11');
frac_d1=x(1);  % fraction of food consumption in 1885 for minimum consumption
mu1=x(2); % weight for food in the utility function
mu2=x(3);
theta1=x(4); % capital contribution in sector 1
eta=x(5); % labor contribution in sector 1
alpha1=x(6); % intermediate input contribution in sector 1
alpha2=x(7); % intermediate input contribution in sector 2
theta2=x(8);  % capital share in sector 2
beta=x(9);  % discounting factor 
phi=x(10); % cost of intermediation
table1=[frac_d1 mu1 mu2 theta1 eta alpha1 alpha2 theta2 beta phi];
format short;
disp('   frac_d1  mu1      mu2     theta1    eta    alpha1    alpha2    theta2   beta    phi');
disp(table1);


% gross up by alpha
theta1=theta1/(1-alpha1);
eta=eta/(1-alpha1);


% Load data on the path of exogenous variables for 1885-1940
x=xlsread('prewar_dataset','input','a10:o65');
nyrs=length(x);
year=x(:,1);
POP=x(:,2);  % poluation in millions
EMP1=x(:,3); % employment in sector 1 in millions
EMP2=x(:,4); % employment in sector 2 in millions
h1=x(:,5); % hours per week in sector 1
h2=x(:,6); % hours per week in sector 2
K1=x(:,7); % capital stock in sector 1
K2=x(:,8); % capital stock in sector 2
q=x(:,9); % deflator, sector 1 relative to sector 2
Y1=x(:,10); % value added, sector 1
Y2=x(:,11); % value added, sector 2
psi=x(:,12); % govt expenditure share
varatio=x(:,13); % gross value-added ratio, sector 1
delta=x(:,14); % time-varying depreciation rate
tau=x(:,15);  % time-varying capital income tax rate
clear x;
EMP=EMP1+EMP2;
K=K1+K2;
sebar=EMP1./EMP;


% Calculate TFP for 1885-1940
x=TFP(Y1,K1,h1,EMP1,Y2,K2,h2,EMP2,q);
TFP1=x(:,1);
TFP2=x(:,2);
clear x;
        

% Parameters for projectiong exogenous variables beyond sample period
x=xlsread('prewar_dataset','parameters','f2:f11');
h1_ss=x(1); % steady-state hours worked per week, sector 1
h2_ss=x(2); % steady-state hours worked per week, sector 2
delta_ss=x(3);  % capital depreciation rate
gf1_ss=x(4); % 1 plus steady-state growth rate of TFP, sector 1
gf2_ss=x(5); % 1 plus steady-state growth rate of TFP, sector 2
n_E_ss=x(6); % 1 plus steady-state value of growth rate of employment
n_N_ss=x(6);  % ss value of pop growth is the same as employment's
psi_ss=x(7); % steady-state value of share of govt expenditure of sector2 output
tau_ss=x(8);  % tax rate on net capital income
Ebar=x(9);  % Lower bound for E1
c1_1885=x(10); % percapita real food (sector 1 good) consumption in 1885
table1=[h1_ss h2_ss delta_ss gf1_ss gf2_ss n_E_ss psi_ss tau_ss c1_1885];
format short;
disp('   h1_ss    h2_ss    delta_ss   gf1_ss    gf2_ss    n_E_ss    psi_ss     tau_ss    c1(1885)');
disp(table1);


% Define trends
% projected values from 1941 on
for t=nyrs+1;
   TFP1(t)=TFP1(t-1)*gf1_ss;
   TFP2(t)=TFP2(t-1)*gf2_ss;
   EMP(t)=EMP(t-1)*n_E_ss;
   POP(t)=POP(t-1)*n_N_ss;
   h1(t)=h1_ss;
   h2(t)=h2_ss;
end;
x=trends(TFP1,TFP2,h1,h2,EMP,POP);
X_Y=x(:,1);
X_Q=x(:,2);
clear x;
gamma2_ss=X_Y(nyrs+1)/X_Y(nyrs);


% calculate rate of return schedule
numcap=161;
X_Q_0=X_Q(baseyear);
X_Y_0=X_Y(baseyear);
d1_0=frac_d1*c1_1885;
se_v=zeros(numcap,1);
r2_v=zeros(numcap,1);
r2_vv=zeros(numcap,1);
kk_v=zeros(numcap,1);
x0=[0.15,0.39];
y0=[0.2,0.2,1];
for i=1:numcap;
    kk=1.39+i/100;
    kk_v(i)=kk;
    options=optimset('Display','none','TolFun',1e-14);   % Option to display output
    x=fsolve('sk_and_qq_given_se',x0,options,kk,rr_0,sebar(baseyear),...
        X_Q_0,X_Y_0,d1_0);
    x0=x;
    sk=x(1);
    se=sebar(baseyear);
    qq=x(2);
    r2_v(i)=r2_f(sk,se,kk,qq)-phi;
    rr_0=0.41555;  % rr in baseyear without barrier
    x=fsolve('sk_se_and_qq',y0,options,kk,rr_0,X_Q_0,X_Y_0,d1_0);
    y0=x;
    sk=x(1);
    se=x(2);
    qq=x(3);
    r2_vv(i)=r2_f(sk,se,kk,qq)-phi;
end;
plot(kk_v,r2_v,'r:',kk_v,r2_vv,'b-'),title('rate of return, sector 2');
legend('with barrier','no barrier');

table1=[kk_v r2_v r2_vv];
disp('kk  r2 with barrier   r2 without');
disp(table1);
dlmwrite('r2_schedule.txt',table1);


diary off;