function F=steady_state_open(x,gamma2_ss,n_E_ss,psi_ss,delta_ss,tau_ss,qq_ss);

global alpha1 alpha2 beta mu1 mu2 phi;
    % alpha1: material input share in sector 1
    % alpha2: material input share in sector 2
    % beta: discounting factor
    % mu1: food share in the utility function
    % mu2: non-food share in the utility function, equals 1-mu1
    % phi: cost of financial intermediation for sector 2 capital

% four-equation system determining SS values of (sk,se,kk,rr)
    % gamma_2_ss: constant growth rate of X_Y (trend for sector 2 output)
    % n_E_ss: constant growth rate of population and employment
    % psi_ss: constant share of government expenditure in sector 2 output
    % delta_ss: constant depreciation rate
    % tau_ss: constant capital income tax rate
    % qq_ss: constant detrended relative price
% x(1) is sk
% x(2) is se
% x(3) is kk
% x(4) is rr

qq=qq_ss;
sk=x(1);
se=x(2);
kk=x(3);
rr=x(4);

F(1)=r1_f(sk,se,kk,qq) - (r2_f(sk,se,kk,qq)-phi); % r1=r2
F(2)=income_ratio_f(sk,se,kk,qq) - 1; % w1h1=w2h2
F(3)=gamma2_ss*n_E_ss*kk...
    - ((1-delta_ss-(1-sk)*phi)*kk ...
    + (1-psi_ss)*y2_f(sk,se,kk,qq) - mu2*rr...
    - alpha1*qq*y1_f(sk,se,kk,qq)...
    + qq*y1_f(sk,se,kk,qq) - mu1*rr ...
    - alpha2*y2_f(sk,se,kk,qq)...
      ); % capital accumulation
F(4)=gamma2_ss - beta*(1+(1-tau_ss)*(r2_f(sk,se,kk,qq)-phi-delta_ss)); % Euler equation
